#include <SimpleOLED.h>


#define DISPLAY_I2C_ADDR 0x3C
#define DISPLAY_WIDTH     128
#define DISPLAY_HEIGHT     64


int sensorPin = A0;    // select the input pin for scanning
int digitalPin = 2;    // select the input pin for scanning
int ledPin = 13;       // led for trigger indication


SimpleOLED Display(DISPLAY_I2C_ADDR, DISPLAY_WIDTH, DISPLAY_HEIGHT);


void setup() 
{
  pinMode(ledPin, OUTPUT);  // led for trigger indication
  Serial.begin(9600);
  if(Display.begin())
  {
    Serial.println("OLED NOT FOUND");
    for(;;);
  }
  else
    Serial.println("OLED OK");
    
  pinMode(digitalPin, INPUT);
    
  Display.clear();
  drawCoordinateSystrem();
}


void drawCoordinateSystrem()
{
  for(uint8_t i = 0; i<DISPLAY_HEIGHT/8-1; i++) 
  {
    Display.setDrawRegion(7, i*8, 1);
    Display.drawBuffer(1, (uint8_t*)"\xff");
  }
  
  Display.setDrawRegion(7, DISPLAY_HEIGHT-8, 1);
  for(int i=0; i<120; i+=10)
    Display.drawBuffer(10, (uint8_t*)"\x0f\x01\x01\x01\x01\x01\x01\x01\x01\x01");
}

void drawGraph(uint8_t *pu8_Values, uint32_t u32_numberOfValues)
{
  uint8_t au8_Buffer[(DISPLAY_HEIGHT/8-1)];
  uint8_t u8_y;
 //uint8_t u8_max=10;
  Display.setDrawRegion(9, 0, (DISPLAY_HEIGHT/8-1));
 
 /*
  for(uint32_t i=0; i<u32_numberOfValues; i++)
  {
    if(u8_max<pu8_Values[i])
      u8_max=pu8_Values[i];
  }*/
  
  for(uint32_t i=0; i<u32_numberOfValues; i++)
  {
    memset(au8_Buffer, 0x0, sizeof(au8_Buffer));
    u8_y=(uint8_t)(((uint32_t)pu8_Values[i])*(DISPLAY_HEIGHT-8)>>8);
    au8_Buffer[DISPLAY_HEIGHT/8-2-(u8_y>>3)]=128>>(u8_y&0x7);
    Display.drawBuffer((DISPLAY_HEIGHT/8-1), au8_Buffer);
  }
}

void getAnalogValues(uint8_t *pu8_Values, uint32_t u32_numberOfValues, bool b_Trigger, uint32_t u32_Delay)
{
  volatile uint32_t j;

  digitalWrite(ledPin, HIGH);
  if(b_Trigger)
  {
    while(analogRead(sensorPin)<100);   // warte auf fallende Taktflanke
    while(analogRead(sensorPin)>100);
  }
  
  for(uint32_t i=0; i<u32_numberOfValues; i++)
  {
    pu8_Values[i] = (uint8_t)(analogRead(sensorPin)>>2);
    for(j=0; j<u32_Delay; j++) ;
  }

  digitalWrite(ledPin, LOW);
}

void getDigitalValues(uint8_t *pu8_Values, uint32_t u32_numberOfValues, bool b_Trigger, uint32_t u32_Delay)
{
  volatile uint32_t j;

  digitalWrite(ledPin, HIGH);
  if(b_Trigger)
  {
    while(!digitalRead(digitalPin));   // warte auf fallende Taktflanke
    while(digitalRead(digitalPin));
  }
  
  for(uint32_t i=0; i<u32_numberOfValues; i++)
  {
    pu8_Values[i] = digitalRead(digitalPin)?0xf0:0x10;
    for(j=0; j<u32_Delay; j++) ;
  }

  digitalWrite(ledPin, LOW);
}


void loop() 
{
  uint8_t graph[120];
  getDigitalValues(graph, 120, true, 2);
  drawGraph(graph, 120);
}
